changeset 58823:46becd97b4c5

Fix spelling mistake in previous changes.
author Glenn Morris <rgm@gnu.org>
date Tue, 07 Dec 2004 12:22:19 +0000
parents 1a6ab2b97c41
children 8da33d42472e
files lisp/calendar/holidays.el
diffstat 1 files changed, 4 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/calendar/holidays.el	Tue Dec 07 12:21:07 2004 +0000
+++ b/lisp/calendar/holidays.el	Tue Dec 07 12:22:19 2004 +0000
@@ -407,9 +407,9 @@
 the form ((MONTH DAY YEAR) STRING), where the date is that of the
 Nth day before or after advent.
 
-For backwards compatability, if this function is called with no
+For backwards compatibility, if this function is called with no
 arguments, then it returns the value appropriate for advent itself."
   ;; Backwards compatability layer.
   (if (not n)
       (holiday-advent 0 "Advent")
     (let ((year displayed-year)
@@ -431,11 +431,11 @@
 the form ((MONTH DAY YEAR) STRING), where the date is that of the
 Nth day before or after Easter.
 
-For backwards compatability, if this function is called with no
+For backwards compatibility, if this function is called with no
 arguments, then it returns a list of \"standard\" Easter-related
 holidays (with more entries if `all-christian-calendar-holidays'
 is non-nil)."
   ;; Backwards compatability layer.
   (if (not n)
       (let (res-list res)
         (dolist (elem (append
@@ -407,9 +407,9 @@
 arguments, then it returns the value appropriate for advent itself."
-  ;; Backwards compatability layer.
+  ;; Backwards compatibility layer.
   (if (not n)
       (holiday-advent 0 "Advent")
@@ -431,11 +431,11 @@
 holidays (with more entries if `all-christian-calendar-holidays'
 is non-nil)."
-  ;; Backwards compatability layer.
+  ;; Backwards compatibility layer.
   (if (not n)
       (let (res-list res)